@@ -1,4 +1,3 @@
-/* $clog: clog.h,v 1.25 2011/06/14 21:16:50 dhill Exp $ */
 /*
  * Copyright (c) 2009, 2010 Marco Peereboom <marco@peereboom.us>
  *
@@ -22,27 +21,22 @@
 #include <clens.h>
 #endif
 
-#include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
-#include <ctype.h>
-#include <unistd.h>
-#include <signal.h>
-#include <netdb.h>
+#include <stdint.h>
 #include <syslog.h>
-#include <errno.h>
-#include <stdarg.h>
-
-#include <sys/socket.h>
-#include <sys/time.h>
 
 /* versioning */
+#define CLOG_STRINGIFY(x)	#x
+#define CLOG_STR(x)		CLOG_STRINGIFY(x)
 #define CLOG_VERSION_MAJOR	0
-#define CLOG_VERSION_MINOR	3
-#define CLOG_VERSION_PATCH	4
-#define CLOG_VERSION		"0.3.4"
+#define CLOG_VERSION_MINOR	4
+#define CLOG_VERSION_PATCH	0
+#define CLOG_VERSION		CLOG_STR(CLOG_VERSION_MAJOR) "." \
+				CLOG_STR(CLOG_VERSION_MINOR) "." \
+				CLOG_STR(CLOG_VERSION_PATCH)
 
-void	clog_version(int *major, int *minor, int *patch);
+const char	*clog_verstring(void);
+void		 clog_version(int *major, int *minor, int *patch);
 
 
 #define CLOG_F_FILE		(1<<0)
@@ -69,26 +63,28 @@ void	clog_set_mask(uint64_t);
 void	clog_dbg_internal(int, int, uint64_t, const char *, const char *, int,
 	    const char *, ...) __attribute__((__format__ (printf, 7, 8)));
 
-/* no errno */
+#define CEMERG(b...)		do { clog_dbg_internal(LOG_EMERG, 1, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CEMERGX(b...)		do { clog_dbg_internal(LOG_EMERG, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CALERT(b...)		do { clog_dbg_internal(LOG_ALERT, 1, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CALERTX(b...)		do { clog_dbg_internal(LOG_ALERT, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CCRIT(b...)		do { clog_dbg_internal(LOG_CRIT, 1, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CCRITX(b...)		do { clog_dbg_internal(LOG_CRIT, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CERR(b...)		do { clog_dbg_internal(LOG_ERR, 1, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CERRX(b...)		do { clog_dbg_internal(LOG_ERR, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CWARN(b...)		do { clog_dbg_internal(LOG_WARNING, 1, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CNWARN(a, b...)		do { clog_dbg_internal(LOG_WARNING, 1, a, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CWARNX(b...)		do { clog_dbg_internal(LOG_WARNING, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CNWARNX(a, b...)	do { clog_dbg_internal(LOG_WARNING, 0, a, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CNNOTICE(a, b...)	do { clog_dbg_internal(LOG_NOTICE, 0, a, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
+#define CNOTICE(b...)		do { clog_dbg_internal(LOG_NOTICE, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
 #define CNINFO(a, b...)		do { clog_dbg_internal(LOG_INFO, 0, a, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
 #define CINFO(b...)		do { clog_dbg_internal(LOG_INFO, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
 #define CNDBG(a, b...)		do { clog_dbg_internal(LOG_DEBUG, 0, a, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
 #define CDBG(b...)		do { clog_dbg_internal(LOG_DEBUG, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
-
-/* errno */
-#define CNWARNX(a, b...)	do { clog_dbg_internal(LOG_WARNING, 0, a, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
-#define CWARNX(b...)		do { clog_dbg_internal(LOG_WARNING, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
-#define CNWARN(a, b...)		do { clog_dbg_internal(LOG_WARNING, 1, a, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
-#define CWARN(b...)		do { clog_dbg_internal(LOG_WARNING, 1, -1llu, __FILE__, __FUNCTION__, __LINE__, b); } while (0)
-
-#define CNFATALX(a, b...)	do { clog_dbg_internal(LOG_CRIT, 0, a, __FILE__, __FUNCTION__, __LINE__, b); exit(1); } while (0)
-#define CFATALX(b...)		do { clog_dbg_internal(LOG_CRIT, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); exit(1); } while (0)
-#define CNFATAL(a, b...)	do { clog_dbg_internal(LOG_CRIT, 1, a, __FILE__, __FUNCTION__, __LINE__, b); exit(1); } while (0)
-#define CFATAL(b...)		do { clog_dbg_internal(LOG_CRIT, 1, -1llu, __FILE__, __FUNCTION__, __LINE__, b); exit(1); } while (0)
-#define CNABORTX(a, b...)	do { clog_dbg_internal(LOG_CRIT, 0, a, __FILE__, __FUNCTION__, __LINE__, b); abort(); } while (0)
-#define CABORTX(b...)		do { clog_dbg_internal(LOG_CRIT, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); abort(); } while (0)
-#define CNABORT(a, b...)	do { clog_dbg_internal(LOG_CRIT, 1, a, __FILE__, __FUNCTION__, __LINE__, b); abort(); } while (0)
-#define CABORT(b...)		do { clog_dbg_internal(LOG_CRIT, 1, -1llu, __FILE__, __FUNCTION__, __LINE__, b); abort(); } while (0)
+#define CFATAL(b...)		do { clog_dbg_internal(LOG_EMERG, 1, -1llu, __FILE__, __FUNCTION__, __LINE__, b); exit(1); } while (0)
+#define CFATALX(b...)		do { clog_dbg_internal(LOG_EMERG, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); exit(1); } while (0)
+#define CABORT(b...)		do { clog_dbg_internal(LOG_EMERG, 1, -1llu, __FILE__, __FUNCTION__, __LINE__, b); abort(); } while (0)
+#define CABORTX(b...)		do { clog_dbg_internal(LOG_EMERG, 0, -1llu, __FILE__, __FUNCTION__, __LINE__, b); abort(); } while (0)
 
 /* old interface */
 void		 clog_init(int);
